0.1.1 - 2024-10-11
==================

### Refactor
- The main `Person` model was renamed to `Resume`

### Features
- Added permission checks to the Simple and List base Plugins

0.1.0 - 2024-10-10
==================

### Initial Release

The CV is kind of working. Editing via Django-Admin or inline via
contenteditable="true" is possible.